@@ -32,8 +32,18 @@ dDAGtip <- function (g)
         stop("The function must apply to either 'igraph' or 'graphNEL' object.\n")
     }
     
-    igr <- dDAGreverse(ig)
-    tips <- dDAGroot(igr)
+    fast <- TRUE
+    if(fast){
+        ## get the outgoing neighbors (including self) that are reachable
+        neighs.out <- igraph::neighborhood(ig, order=1, nodes=V(ig), mode="out")
+        ## calculate the number of neighors (including self)
+        num.neighs.out <- sapply(neighs.out, length)
+        ## find the tips that does not have any outgoing neighbors (except self)
+        tips <- V(ig)[num.neighs.out==1]$name
+    }else{
+        igr <- dDAGreverse(ig)
+        tips <- dDAGroot(igr)
+    }
     
     return(tips)
 }
\ No newline at end of file
