@@ -4,17 +4,16 @@
 library(dnet)
 
 # Load or install packages specifically used in this demo
-if(!require(affy)){
-    install.packages("affy",repos="http://www.stats.bris.ac.uk/R")
-    library(affy)
-}
-if(!require(limma)){
-    install.packages("limma",repos="http://www.stats.bris.ac.uk/R")
-    library(limma)
+for(pkg in c("Biobase","limma")){
+    if(!require(pkg, character.only=T)){
+        source("http://bioconductor.org/biocLite.R")
+        biocLite(pkg)
+        lapply(pkg, library, character.only=T)
+    }
 }
 
 # This dataset involves 130 patients with chronic lymphocytic leukemia (CLL). When enrolled in the study, these CLL patients had not received prior therapy for CLL. Additional covariate about sampling time to first treatment (years) is available. The dataset has been normalised and log2-transformed, and provided as an "ExpressionSet" object.
-load(url("http://dnet.r-forge.r-project.org/data/Datasets/CLL.RData"))
+CLL <- dRDataLoader(RData='CLL')
 CLL
 
 # Non-specific probesets filtering: the signals below log2(30) are considered as being technically unreliable (i.e. an empirically determined value of minimum sensitivity). Also, those probesets with >70% of samples having technically unriliable signals were excluded from further consideration
@@ -54,8 +53,8 @@ prob2gene <- function(eset){
 esetGene <- prob2gene(esetNew)
 esetGene
 
-# An igraph object that contains a functional protein association network in human. The network is extracted from the STRING database (version 9.0.5). Only those associations with medium confidence (score>=0.4) are retained.
-load(url("http://dnet.r-forge.r-project.org/data/Hs/org.Hs.string.RData"))
+# An igraph object that contains a functional protein association network in human. The network is extracted from the STRING database (version 9.1). Only those associations with medium confidence (score>=400) are retained.
+org.Hs.string <- dRDataLoader(RData='org.Hs.string')
 org.Hs.string
 
 # extract network that only contains genes in esetGene
@@ -108,8 +107,8 @@ g <- dNetPipeline(g=network, pval=pval, nsize=20)
 glayout <- layout.fruchterman.reingold(g)
 
 # 3) color nodes according to communities identified via a spin-glass model and simulated annealing
-#com <- spinglass.community(g, spins=3)
-com <- walktrap.community(g, modularity=T)
+#com <- walktrap.community(g, modularity=T)
+com <- spinglass.community(g, spins=25)
 com$csize <- sapply(1:length(com),function(x) sum(com$membership==x))
 vgroups <- com$membership
 colormap <- "yellow-darkorange"
