@@ -8,10 +8,10 @@
 library(dnet)
 
 # Load or install packages specifically used in this demo
-list.pkg <- c("affy","limma")
-for(pkg in list.pkg){
+for(pkg in c("Biobase","limma")){
     if(!require(pkg, character.only=T)){
-        install.packages(pkg,repos="http://www.stats.bris.ac.uk/R",dependencies=TRUE)
+        source("http://bioconductor.org/biocLite.R")
+        biocLite(pkg)
         lapply(pkg, library, character.only=T)
     }
 }
@@ -58,8 +58,8 @@ prob2gene <- function(eset){
 esetGene <- prob2gene(eset)
 esetGene
 
-# An igraph object that contains a functional protein association network in human. The network is extracted from the STRING database (version 9.0.5). Only those associations with medium confidence (score>=0.4) are retained.
-load(url("http://dnet.r-forge.r-project.org/data/Hs/org.Hs.string.RData"))
+# An igraph object that contains a functional protein association network in human. The network is extracted from the STRING database (version 9.1). Only those associations with medium confidence (score>=400) are retained.
+org.Hs.string <- dRDataLoader(RData='org.Hs.string')
 org.Hs.string
 
 # extract network that only contains genes in esetGene
@@ -128,12 +128,12 @@ apply(adjpvals<1e-2, 2, sum)
 fdr <- dSVDsignif(data=D, num.eigen=NULL, pval.eigen=1e-2, signif="fdr", orient.permutation="row", num.permutation=200, fdr.procedure="stepup", verbose=T)
 
 # 2) identification of module
-g <- dNetPipeline(g=network, pval=fdr, method="fdr", nsize=30)
+g <- dNetPipeline(g=network, pval=fdr, method="customised", nsize=30)
 glayout <- layout.fruchterman.reingold(g)
 
 # 3) color nodes according to communities identified via a spin-glass model and simulated annealing
-#com <- spinglass.community(g, spins=3)
-com <- walktrap.community(g, modularity=T)
+#com <- walktrap.community(g, modularity=T)
+com <- spinglass.community(g, spins=25)
 com$csize <- sapply(1:length(com),function(x) sum(com$membership==x))
 vgroups <- com$membership
 colormap <- "yellow-darkorange"
