@@ -29,33 +29,36 @@ fd[1:3,]
 md <- exprs(eset)
 md[1:3,1:3]
 # number of samples for each cancer type
-table(pData(eset)$TCGA_tumor_type)
 tumor_type <- sort(unique(pData(eset)$TCGA_tumor_type))
-
-# Kaplan-Meier survival curves for individual tumor types
-fit <- survfit(Surv(time, status) ~ TCGA_tumor_type, data=pd, type=c("kaplan-meier","fh")[1])
-plot(fit, xscale=365.25, xlab = "Years", ylab="Survival", lty=1:2, col=rainbow(length(tumor_type))) 
-legend("topright", tumor_type, lty=1:2, col=rainbow(length(tumor_type)))
+table(pData(eset)$TCGA_tumor_type)
 
 # Survival analysis across tumor types using Cox proportional hazards model
 # Cox regression yields an equation for the hazard/risk as a function of several explanatory variables
-# Except for the gene mutational data in subject,  other explanatory variables (or called covariates) include: age, gender, and tumor type
+
+## fit a Cox proportional hazards model for age, gender, tumor type
+data <- pd
+fit <- survival::coxph(Surv(time,status) ~ Age + Gender + TCGA_tumor_type, data=data)
+res <- anova(fit, test="Chisq")
+
+## Now with gene mutational data in subject, adjust for other explanatory variables (or called covariates) include: age, gender, and tumor type
 ## only those genes with mutations at least 1% of samples will be analysed
 flag <- sapply(1:nrow(md), function(i) ifelse(sum(md[i,]!=0)>=0.01*ncol(md), T, F))
 esetGene <- eset[flag, ]
 md_selected <- md[flag,]
 ## survival analysis to obtain hazard ratio (HR) and pvaules
-gene_signif <- matrix(1, nrow=nrow(md_selected), ncol=2)
-rownames(gene_signif) <- rownames(md_selected)
-colnames(gene_signif) <- c("HR", "pvalue")
+HR <- rep(1, nrow(md_selected))
+pvals <- rep(1, nrow(md_selected))
 for(i in 1:nrow(md_selected)){
     ## fit a Cox proportional hazards model
     data <- cbind(pd, gene=md_selected[i,])
-    fit <- coxph(formula=Surv(time,status) ~ Age + Gender + TCGA_tumor_type + gene, data=data)
-    gene_signif[i,] <- as.matrix(anova(fit))[5,c(2,4)]
+    fit <- survival::coxph(formula=Surv(time,status) ~ Age + Gender + TCGA_tumor_type + gene, data=data)
+    ## ANOVA (Chisq test)
+    res <- as.matrix(anova(fit, test="Chisq"))
+    HR[i] <- res[5,2]
+    pvals[i] <- res[5,4]
 }
-HR <- gene_signif[,1]
-pvals <- gene_signif[,2]
+names(HR) <- rownames(md_selected)
+names(pvals) <- rownames(md_selected)
 
 # An igraph object that contains a functional protein association network in human. The network is extracted from the STRING database (version 9.1). Only those associations with medium confidence (score>=400) are retained.
 org.Hs.string <- dRDataLoader(RData='org.Hs.string')
@@ -77,33 +80,32 @@ net
 
 # visualisation of the gene-active network itself
 ## the layout of the network visualisation (fixed in different visuals) 
-g <- net
-glayout <- layout.fruchterman.reingold(g)
+glayout <- layout.fruchterman.reingold(net)
 ## color nodes according to communities (identified via a spin-glass model and simulated annealing)
-com <- spinglass.community(g, spins=25)
+com <- spinglass.community(net, spins=25)
 com$csize <- sapply(1:length(com),function(x) sum(com$membership==x))
 vgroups <- com$membership
 colormap <- "yellow-darkorange"
 palette.name <- visColormap(colormap=colormap)
 mcolors <- palette.name(length(com))
 vcolors <- mcolors[vgroups]
-com$significance <- dCommSignif(g, com)
+com$significance <- dCommSignif(net, com)
 ## node sizes according to degrees
-vdegrees <- igraph::degree(g)
+vdegrees <- igraph::degree(net)
 ## highlight different communities
 mark.groups <- communities(com)
 mark.col <- visColoralpha(mcolors, alpha=0.2)
 mark.border <- visColoralpha(mcolors, alpha=0.2)
-edge.color <- c("#C0C0C0", "#000000")[crossing(com,g)+1]
+edge.color <- c("#C0C0C0", "#000000")[crossing(com,net)+1]
 edge.color <- visColoralpha(edge.color, alpha=0.5)
 ## visualise the subnetwrok
-visNet(g, glayout=glayout, vertex.label=V(g)$geneSymbol, vertex.color=vcolors, vertex.frame.color=vcolors, vertex.shape="sphere", mark.groups=mark.groups, mark.col=mark.col, mark.border=mark.border, mark.shape=1, mark.expand=10, edge.color=edge.color, newpage=F, vertex.label.color="blue", vertex.label.dist=0.4, vertex.label.font=2)
+visNet(g=net, glayout=glayout, vertex.label=V(net)$geneSymbol, vertex.color=vcolors, vertex.frame.color=vcolors, vertex.shape="sphere", mark.groups=mark.groups, mark.col=mark.col, mark.border=mark.border, mark.shape=1, mark.expand=10, edge.color=edge.color, newpage=F, vertex.label.color="blue", vertex.label.dist=0.4, vertex.label.font=2)
 legend_name <- paste("C",1:length(mcolors)," (n=",com$csize,", pval=",signif(com$significance,digits=2),")",sep='')
 legend("topleft", legend=legend_name, fill=mcolors, bty="n", cex=0.6)
 
 # fit a Cox proportional hazards model using the subnetwork
 ## for the whole network
-data_g <- t(md[V(g)$name,])
+data_g <- t(md[V(net)$name,])
 data_g <- apply(data_g!=0, 1, sum)
 data <- cbind(pd, net=data_g)
 fit <- coxph(formula=Surv(time,status) ~ Age + Gender + TCGA_tumor_type + net, data=data)
@@ -111,7 +113,7 @@ res <- as.matrix(anova(fit))
 HR_g <- res[5,2]
 pvals_g <- res[5,4]
 ## for the cumulative nodes from the network
-cg_names <- names(sort(HR[V(g)$name], decreasing=T))
+cg_names <- names(sort(HR[V(net)$name], decreasing=T))
 cg_signif <- matrix(1, nrow=length(cg_names), ncol=2)
 rownames(cg_signif) <- cg_names
 colnames(cg_signif) <- c("HR", "pvalue")
@@ -128,12 +130,13 @@ for(i in 1:length(cg_names)){
     cg_signif[i,] <- res[5,c(2,4)]
 }
 cg_signif[cg_signif[,2]==0,2] <- min(cg_signif[cg_signif[,2]!=0,2])
-bp.HR.list <- list(All=HR, Neti=HR[cg_names], Netc=cg_signif[2:nrow(cg_signif),1])
+naive <- sample(HR, length(cg_names))
+bp.HR.list <- list(All=naive, Neti=HR[cg_names], Netc=cg_signif[2:nrow(cg_signif),1])
 par(las=2, mar=c(10,8,4,2)) # all axis labels horizontal
 boxplot(bp.HR.list, outline=F, horizontal=F, names=c("naive\n(genes in random)", "dnet\n(genes individually)", "dnet \n(genes in combination)"), col=c("red","green","blue"), ylab="Cox hazard ratio (HR)", log="y", ylim=c(0.1,100))
 # Two-sample Kolmogorov-Smirnov test
 ## Genes randomly choosen versus genes in the network (used individually)
-stats::ks.test(x=HR, y=HR[cg_names], alternative="two.sided", exact=NULL)
+stats::ks.test(x=naive, y=HR[cg_names], alternative="two.sided", exact=NULL)
 ## Genes in the network (used individually) versuse genes in the network (used in combination)
 stats::ks.test(x=HR[cg_names], y=cg_signif[2:nrow(cg_signif),1], alternative="two.sided", exact=NULL)
 
@@ -144,13 +147,13 @@ frac_mutated <- sapply(tumor_type, function(x) {
     apply(exprs(e)!=0,1,sum)/ncol(e)
 })
 rownames(frac_mutated) <- fData(eset)$Symbol
-data <- frac_mutated[V(g)$name,]
-sReorder <- dNetReorder(g, data, feature="edge", node.normalise="degree", amplifier=3, metric="none")
-visNetReorder(g=g, data=data, sReorder=sReorder, height=ceiling(sqrt(ncol(data)))*3, newpage=T, glayout=glayout, colormap="lightyellow-orange", vertex.label=NA,vertex.shape="sphere", vertex.size=16,mtext.cex=0.8,border.color="888888", zlim=c(0,0.12), mark.groups=mark.groups, mark.col=mark.col, mark.border=mark.border, mark.shape=1, mark.expand=10, edge.color=edge.color)
+data <- frac_mutated[V(net)$name,]
+sReorder <- dNetReorder(g=net, data, feature="edge", node.normalise="degree", amplifier=3, metric="none")
+visNetReorder(g=net, data=data, sReorder=sReorder, height=ceiling(sqrt(ncol(data)))*3, newpage=T, glayout=glayout, colormap="darkgreen-lightgreen-lightpink-darkred", vertex.label=NA,vertex.shape="sphere", vertex.size=16,mtext.cex=0.8,border.color="888888", zlim=c(0,0.1), mark.groups=mark.groups, mark.col=mark.col, mark.border=mark.border, mark.shape=1, mark.expand=10, edge.color=edge.color)
 
 # output the subnetwork and their mutation frequency data
 ## Write the subnetwork into a SIF-formatted file (Simple Interaction File)
-sif <- data.frame(source=get.edgelist(g)[,1], type="interaction", target=get.edgelist(g)[,2])
+sif <- data.frame(source=get.edgelist(net)[,1], type="interaction", target=get.edgelist(net)[,2])
 write.table(sif, file=paste("Survival_TCGA.sif", sep=""), quote=F, row.names=F,col.names=F,sep="\t")
 ## Output the corresponding mutation frequency data
 hmap <- data.frame(Symbol=rownames(data), data)
@@ -173,7 +176,9 @@ dev.new()
 hist(ubiquity,20, xlab="Cross-tumor mutation ubiquity", xlim=c(0,1))
 
 # GSEA using the network as a gene set against the cross-tumor mutation ubiquity and each tumor type
-eTerm <- dGSEA(data=cbind(frac_mutated,ubiquity), identity="symbol", genome="Hs", ontology="Customised", customised.genesets=V(g)$name, weight=0, nperm=2000)
+customised.genesets <- list(net=V(net)$name)
+eTerm <- dGSEA(data=cbind(ubiquity, frac_mutated), identity="symbol", genome="Hs", ontology="Customised", customised.genesets=customised.genesets, weight=0, nperm=2000)
+## Comparing normalised enrichement score (NES)
 frac_pvalue <- as.vector(eTerm$pvalue)
 frac_fdr <- stats::p.adjust(frac_pvalue, method="BH")
 frac_nes <- as.vector(eTerm$nes)
@@ -187,26 +192,29 @@ par(las=1) # make label text perpendicular to axis
 par(mar=c(5,8,4,2)) # increase y-axis margin.
 z <- data[,2]
 barY <- barplot(z, xlab="Normalised enrichment score (NES)", horiz=TRUE, names.arg=rownames(data), cex.names=0.7, cex.lab=0.7, cex.axis=0.7, col="transparent")
+## GSEA plot for ubiquity
+visGSEA(eTerm, which_sample=1)
 
 # Evolutionary analysis for genes in the subnetwork
 ## get a list of genes in the subnetwork
-data <- V(net)$name
-eTerm <- dEnricher(data, identity="symbol", genome="Hs", ontology="PS2", sizeRange=c(10,20000), min.overlap=0)
+eTerm <- dEnricher(data=V(net)$name, identity="symbol", genome="Hs", ontology="PS2", sizeRange=c(10,20000), min.overlap=0)
 ## Look at the evolution relevance along the path to the eukaryotic common ancestor
-cbind(eTerm$set_info[,2:3], nSet=sapply(eTerm$gs,length), nOverlap=sapply(eTerm$overlap,length), zscore=eTerm$zscore, pvalue=eTerm$pvalue, adjp=eTerm$adjp)
+output <- dEnricherView(eTerm, top_num=NULL, sortBy="none", details=TRUE)
+write.table(output, file="enrichment_PS2.txt", quote=F, row.names=F,col.names=T,sep="\t")
+output
 ## load Entrezgene info
 org.Hs.eg <- dRDataLoader(RData='org.Hs.eg')
 gene_info <- org.Hs.eg$gene_info
 entrez <- unlist(eTerm$overlap[6], use.names=F)
 ## build neighbor-joining tree
-data <- frac_mutated[V(g)$name,]
+data <- frac_mutated[V(net)$name,]
 tree_bs <- visTreeBootstrap(t(data), nodelabels.arg=list(cex=0.7,bg="white-pink-violet"), metric=c("euclidean","pearson","spearman","cos","manhattan","kendall","mi")[3], num.bootstrap=2000, plot.phylo.arg=list(cex=1, edge.width=1.2))
 flag <- match(tree_bs$tip.label, colnames(data))
 base <- sapply(eTerm$overlap, function(x){
     as.character(gene_info[match(x,rownames(gene_info)),2])
 })
+## reordering via hierarchical clustering
 if(1){
-    ## reordering via hierarchical clustering
     cluster_order <- matrix(1, nrow=length(base))
     base_order <- matrix(1, nrow=length(base))
     for(i in 1:length(base)){
@@ -231,7 +239,7 @@ if(1){
 }
 RowSideColors <- sapply(1:length(base), function(x) base_order==x)
 RowSideColors <- t(RowSideColors)
-rslab <- ifelse(eTerm$adjp<0.05 & sapply(eTerm$overlap,length)>=3," (FDR<0.05)","")
+rslab <- ifelse(eTerm$adjp<0.05," (FDR<0.05)","")
 rslab <- paste(gsub(".*:","",eTerm$set_info$name), rslab, sep="")
 rownames(RowSideColors) <- rslab
 colnames(RowSideColors) <- rownames(data)
@@ -240,7 +248,7 @@ RowSideColors <- RowSideColors[, ordering]
 base_order1 <- base_order[ordering]
 basesep_index <- sapply(unique(base_order1), function(x) which(base_order1[length(base_order1):1]==x)[1])
 basesep_index <- basesep_index[1:length(basesep_index)-1]
-labRow <- sapply(pvals[match(V(g)$name, names(pvals))], function(x){
+labRow <- sapply(pvals[match(V(net)$name, names(pvals))], function(x){
     if(x < 0.005){
         " ***"
     }else if(x < 0.01){
@@ -255,8 +263,7 @@ labRow <- paste(rownames(data), labRow, sep="")
 visHeatmapAdv(data=data[ordering,flag], Rowv=F, Colv=F, colormap="lightyellow-orange", zlim=c(0,0.12), keysize=1.5, RowSideColors=RowSideColors, RowSideWidth=2, RowSideLabelLocation="top", add.expr=abline(h=(basesep_index-0.5), lty=2,lwd=1,col="black"), offsetRow=-0.5, labRow=labRow[ordering], KeyValueName="Frequency", margins=c(6,6))
 
 # Cross-tumor mutation ubiquity versus common ancestors
-g <- net
-ind <- match(V(g)$name, rownames(ubiquity))
+ind <- match(V(net)$name, rownames(ubiquity))
 net_ubiquity <- ubiquity[ind]
 net_ubiquity <- net_ubiquity[ordering]
 names(net_ubiquity) <- rownames(data)[ordering]
@@ -273,14 +280,18 @@ stats::ks.test(x=net_ubiquity[base_order1==6], y=net_ubiquity[base_order1<6], al
 stats::ks.test(x=net_ubiquity[base_order1==6], y=net_ubiquity[base_order1>6], alternative="two.sided", exact=NULL)
 
 # GOBP enrichment analysis
-data <- V(net)$name
-eTerm <- dEnricher(data, identity="symbol", genome="Hs", ontology="GOBP")
+eTerm <- dEnricher(data=V(net)$name, identity="symbol", genome="Hs", ontology="GOBP")
+## write into the file called 'enrichment_GOBP.txt'
+output <- dEnricherView(eTerm, top_num=NULL, sortBy="adjp", details=TRUE)
+write.table(output, file="enrichment_GOBP.txt", quote=F, row.names=F,col.names=T,sep="\t")
 ## visualise the top significant terms in the GOBP heirarchy
 ## first, load the GOBP ontology
 ig.GOBP <- dRDataLoader(RData='ig.GOBP')
 g <- ig.GOBP
 ## select the top most significant 10 terms
-nodes_query <- names(sort(eTerm$adjp)[1:10])
+top <- dEnricherView(eTerm, top_num=10, details=TRUE)
+top
+nodes_query <- rownames(top)
 nodes.highlight <- rep("red", length(nodes_query))
 names(nodes.highlight) <- nodes_query
 ## induce the shortest paths (one for each significant term) to the ontology root
@@ -289,14 +300,18 @@ subg <- dDAGinduce(g, nodes_query, path.mode="shortest_paths")
 visDAG(g=subg, data=-1*log10(eTerm$adjp[V(subg)$name]), node.info="both", node.attrs=list(color=nodes.highlight))
 
 # GOMF enrichment analysis
-data <- V(net)$name
-eTerm <- dEnricher(data, identity="symbol", genome="Hs", ontology="GOMF")
+eTerm <- dEnricher(data=V(net)$name, identity="symbol", genome="Hs", ontology="GOMF")
+## write into the file called 'enrichment_GOMF.txt'
+output <- dEnricherView(eTerm, top_num=NULL, sortBy="adjp", details=TRUE)
+write.table(output, file="enrichment_GOMF.txt", quote=F, row.names=F,col.names=T,sep="\t")
 ## visualise the top significant terms in the GOMF heirarchy
 ## first, load the GOMF ontology
 ig.GOMF <- dRDataLoader(RData='ig.GOMF')
 g <- ig.GOMF
 ## select the top most significant 10 terms
-nodes_query <- names(sort(eTerm$adjp)[1:10])
+top <- dEnricherView(eTerm, top_num=10, details=TRUE)
+top
+nodes_query <- rownames(top)
 nodes.highlight <- rep("red", length(nodes_query))
 names(nodes.highlight) <- nodes_query
 ## induce the shortest paths (one for each significant term) to the ontology root
@@ -305,14 +320,19 @@ subg <- dDAGinduce(g, nodes_query, path.mode="shortest_paths")
 visDAG(g=subg, data=-1*log10(eTerm$adjp[V(subg)$name]), node.info="both", node.attrs=list(color=nodes.highlight))
 
 # MP enrichment analysis
-data <- V(net)$name
-eTerm <- dEnricher(data, identity="symbol", genome="Hs", ontology="MP", ontology.algorithm="elim")
+#eTerm <- dEnricher(data=V(net)$name, identity="symbol", genome="Hs", ontology="MP", ontology.algorithm="elim")
+eTerm <- dEnricher(data=V(net)$name, identity="symbol", genome="Hs", ontology="MP", min.overlap=4)
+## write into the file called 'enrichment_MP.txt'
+output <- dEnricherView(eTerm, top_num=NULL, sortBy="adjp", details=TRUE)
+write.table(output, file="enrichment_MP.txt", quote=F, row.names=F,col.names=T,sep="\t")
 ## visualise the top significant terms in the MP heirarchy
 ## first, load the MP ontology
 ig.MP <- dRDataLoader(RData='ig.MP')
 g <- ig.MP
 ## select the top most significant 10 terms
-nodes_query <- names(sort(eTerm$pvalue)[1:10])
+top <- dEnricherView(eTerm, top_num=10, details=TRUE)
+top
+nodes_query <- rownames(top)
 nodes.highlight <- rep("red", length(nodes_query))
 names(nodes.highlight) <- nodes_query
 ## induce all possible paths to the ontology root
@@ -321,14 +341,19 @@ subg <- dDAGinduce(g, nodes_query)
 visDAG(g=subg, data=-1*log10(eTerm$adjp[V(subg)$name]), node.info=c("none","term_id","term_name","both","full_term_name")[5], layout.orientation=c("left_right","top_bottom","bottom_top","right_left")[1], node.attrs=list(color=nodes.highlight))
 
 # DO enrichment analysis
-data <- V(net)$name
-eTerm <- dEnricher(data, identity="symbol", genome="Hs", ontology="DO", ontology.algorithm="pc")
+#eTerm <- dEnricher(data=V(net)$name, identity="symbol", genome="Hs", ontology="DO", ontology.algorithm="pc")
+eTerm <- dEnricher(data=V(net)$name, identity="symbol", genome="Hs", ontology="DO")
+## write into the file called 'enrichment_DO.txt'
+output <- dEnricherView(eTerm, top_num=NULL, sortBy="adjp", details=TRUE)
+write.table(output, file="enrichment_DO.txt", quote=F, row.names=F,col.names=T,sep="\t")
 ## visualise the top significant terms in the DO heirarchy
 ## first, load the DO ontology
 ig.DO <- dRDataLoader(RData='ig.DO')
 g <- ig.DO
 ## select the top most significant 10 terms
-nodes_query <- names(sort(eTerm$adjp)[1:10])
+top <- dEnricherView(eTerm, top_num=10, details=TRUE)
+top
+nodes_query <- rownames(top)
 nodes.highlight <- rep("red", length(nodes_query))
 names(nodes.highlight) <- nodes_query
 ## induce all possible shortest paths to the ontology root
@@ -337,45 +362,31 @@ subg <- dDAGinduce(g, nodes_query)
 visDAG(g=subg, data=-1*log10(eTerm$adjp[V(subg)$name]), node.info="both", zlim=c(0,4), node.attrs=list(color=nodes.highlight))
 
 # Pathway enrichment analysis
-data <- V(net)$name
 ## uisng CP
-eTerm <- dEnricher(data, identity="symbol", genome="Hs", ontology="MsigdbC2CP", min.overlap=2)
-nodes_query <- names(sort(eTerm$pvalue)[1:10])
-cbind(eTerm$set_info[nodes_query,2:3], cbind(nSet=sapply(eTerm$gs,length), nOverlap=sapply(eTerm$overlap,length), zscore=eTerm$zscore, pvalue=eTerm$pvalue, adjp=eTerm$adjp)[nodes_query,])
+eTerm <- dEnricher(data=V(net)$name, identity="symbol", genome="Hs", ontology="MsigdbC2CP")
+dEnricherView(eTerm, top_num=10, sortBy="adjp", details=TRUE)
 ## using KEGG
-eTerm <- dEnricher(data, identity="symbol", genome="Hs", ontology="MsigdbC2KEGG")
-nodes_query <- names(sort(eTerm$pvalue)[1:10])
-cbind(eTerm$set_info[nodes_query,2:3], cbind(nSet=sapply(eTerm$gs,length), nOverlap=sapply(eTerm$overlap,length), zscore=eTerm$zscore, pvalue=eTerm$pvalue, adjp=eTerm$adjp)[nodes_query,])
+eTerm <- dEnricher(data=V(net)$name, identity="symbol", genome="Hs", ontology="MsigdbC2KEGG")
+dEnricherView(eTerm, top_num=10, sortBy="adjp", details=TRUE)
 ## uisng REACTOME
-eTerm <- dEnricher(data, identity="symbol", genome="Hs", ontology="MsigdbC2REACTOME")
-nodes_query <- names(sort(eTerm$pvalue)[1:10])
-cbind(eTerm$set_info[nodes_query,2:3], cbind(nSet=sapply(eTerm$gs,length), nOverlap=sapply(eTerm$overlap,length), zscore=eTerm$zscore, pvalue=eTerm$pvalue, adjp=eTerm$adjp)[nodes_query,])
+eTerm <- dEnricher(data=V(net)$name, identity="symbol", genome="Hs", ontology="MsigdbC2REACTOME")
+dEnricherView(eTerm, top_num=10, sortBy="adjp", details=TRUE)
 ## uisng BIOCARTA
-eTerm <- dEnricher(data, identity="symbol", genome="Hs", ontology="MsigdbC2BIOCARTA", min.overlap=2)
-nodes_query <- names(sort(eTerm$pvalue)[1:5])
-cbind(eTerm$set_info[nodes_query,2:3], cbind(nSet=sapply(eTerm$gs,length), nOverlap=sapply(eTerm$overlap,length), zscore=eTerm$zscore, pvalue=eTerm$pvalue, adjp=eTerm$adjp)[nodes_query,])
+eTerm <- dEnricher(data=V(net)$name, identity="symbol", genome="Hs", ontology="MsigdbC2BIOCARTA", min.overlap=2)
+dEnricherView(eTerm, top_num=10, sortBy="adjp", details=TRUE)
 
 # SCOP superfamily domain enrichment analysis
-data <- V(net)$name
-eTerm <- dEnricher(data, identity="symbol", genome="Hs", ontology="SF")
-nodes_query <- names(sort(eTerm$pvalue)[1:10])
-cbind(eTerm$set_info[nodes_query,2:3], cbind(nSet=sapply(eTerm$gs,length), nOverlap=sapply(eTerm$overlap,length), zscore=eTerm$zscore, pvalue=eTerm$pvalue, adjp=eTerm$adjp)[nodes_query,])
+eTerm <- dEnricher(data=V(net)$name, identity="symbol", genome="Hs", ontology="SF")
+dEnricherView(eTerm, top_num=10, sortBy="adjp", details=TRUE)
 
 # DGIdb druggable gene category enrichment analysis
-data <- V(net)$name
-eTerm <- dEnricher(data, identity="symbol", genome="Hs", ontology="DGIdb", sizeRange=c(10,5000), min.overlap=2)
-nodes_query <- names(sort(eTerm$pvalue)[1:10])
-cbind(eTerm$set_info[nodes_query,2:3], cbind(nSet=sapply(eTerm$gs,length), nOverlap=sapply(eTerm$overlap,length), zscore=eTerm$zscore, pvalue=eTerm$pvalue, adjp=eTerm$adjp)[nodes_query,])
+eTerm <- dEnricher(data=V(net)$name, identity="symbol", genome="Hs", ontology="DGIdb", sizeRange=c(10,5000), min.overlap=2)
+dEnricherView(eTerm, top_num=10, sortBy="adjp", details=F)
 
 # TFBS enrichment analysis
-data <- V(net)$name
-eTerm <- dEnricher(data, identity="symbol", genome="Hs", ontology="MsigdbC3TFT")
-nodes_query <- names(sort(eTerm$pvalue)[1:10])
-cbind(eTerm$set_info[nodes_query,2:3], cbind(nSet=sapply(eTerm$gs,length), nOverlap=sapply(eTerm$overlap,length), zscore=eTerm$zscore, pvalue=eTerm$pvalue, adjp=eTerm$adjp)[nodes_query,])
+eTerm <- dEnricher(data=V(net)$name, identity="symbol", genome="Hs", ontology="MsigdbC3TFT")
+dEnricherView(eTerm, top_num=10, sortBy="adjp", details=F)
 
 # miRNA target enrichment analysis
-data <- V(net)$name
-eTerm <- dEnricher(data, identity="symbol", genome="Hs", ontology="MsigdbC3MIR")
-nodes_query <- names(sort(eTerm$pvalue)[1:10])
-cbind(eTerm$set_info[nodes_query,2:3], cbind(nSet=sapply(eTerm$gs,length), nOverlap=sapply(eTerm$overlap,length), zscore=eTerm$zscore, pvalue=eTerm$pvalue, adjp=eTerm$adjp)[nodes_query,])
-
+eTerm <- dEnricher(data=V(net)$name, identity="symbol", genome="Hs", ontology="MsigdbC3MIR")
+dEnricherView(eTerm, top_num=10, sortBy="adjp", details=F)
