@@ -206,13 +206,6 @@ list(
                 "CLL",
                 "TCGA_mutations"
             )
-        ),
-        sd_section("Domain-centric databases in Eukaryotes",
-            "These databases are used for domain-centric analysis.",
-            c(
-                "Ancestral_domainome",
-                "eTOL"
-            )
         )
     ),
     
